unit cRR9000_Head;

interface

Const
    COM1 = 0;
    COM2 = 1;
    COM3 = 2;
    COM4 = 3;
    COM5 = 4;
    COM6 = 5;
    COM7 = 6;
    COM8 = 7;
    COM9 = 8;
    COM10 = 9;


    OK			    		= $00;
    LengthError         = $01;
    OperationNotSupport = $02;
    RfClosed            = $05;
    EEPROM              = $06;
    TimeOut             = $0a;
    MoreUID             = $0b;
    ISOError            = $0c;
    NoElectronicTag     = $0e;
    OperationError      = $0f;


    CmdNotSupport                 = $01;
    CmdNotIdentify                = $02;
    OperationNotSupport_          = $03;
    UnknownError                  = $0f;
    BlockError                    = $10;
    BlockLockedAndCntLock         = $11;
    BlockLockedAndCntWrite        = $12;
    BlockCntOperate               = $13;
    BlockCntLock                  = $14;


    
    CommunicationErr = $30;
    RetCRCErr        = $31;

    RetDataErr       = $32;    //data length error
    CommunicationBusy= $33;

    Function RR9001_GetBlockSize_BlockNum(Firmcode,OtherCode : Byte;
                                          Var FirmName : String;
                                          Var BlockSize,BlockNum : Byte;
                                          Var BlockStyle : String) : Boolean;
    Function RR9001_GetErrorCodeDesc(errorCode : Byte) : String;
    Function RR9001_GetReturnCodeDesc(retCode : Byte) : String;

implementation

{
Manufacturer Name   Manufacturer code   block information   writing type command
		block count   block capacity		type A  type B
Infineon (ISO Address mode)	0x05	256(user range 0249)	4 bytes	-	
		64(user range057)	4 bytes	-	
STMicroelectronics (LRI512)	0x02	16(user range0~15)	4 bytes	-	
Fujitsu (MB89R116)	0x08	256(user range0249)	8 bytes		
Philips (I-Code SLI)	0x04	32(user range027)	4 bytes	-	
Texas Instruments (Tag-it HF-I)	0x07	64(user range063)	4 bytes		-

   EM Microelectronic  (EM4034-)  0X16  14(user range 3-13)  4 bytes //2006-8-2
}
Function RR9001_GetBlockSize_BlockNum(Firmcode,OtherCode : Byte;
                                      Var FirmName : String;
                                      Var BlockSize,BlockNum : Byte;
                                      Var BlockStyle : String) : Boolean;
Begin
   result := true;
   case FirmCode of
       $05 :
           Begin
               FirmName := 'Infineon';   //(ISO Address mode)
               BlockSize:= 4;
               BlockNum := 58;
               if OtherCode=$E0 then BlockNum := 250
               else if OtherCode=$60 then BlockNum := 58;

               BlockStyle := 'B';   //type B
           end;
       $02 :
           Begin
               FirmName := 'STMicroelectronics';   //(LRI512)
               BlockSize:= 4;
               BlockNum := 16;

               BlockStyle := 'B';   //type B
           end;
       $08 :
           Begin
               FirmName := 'Fujitsu';    //(MB89R116)
               BlockSize:= 8;
               BlockNum := 250;

               BlockStyle := 'AB';   //type AB
           end;
       $04 :
           Begin
               FirmName := 'Philips Semiconductors';   //(I-Code SLI)
               BlockSize:= 4;
               BlockNum := 28;

               BlockStyle := 'B';   //type B
           end;
       $07 :
           Begin
               FirmName := 'Texas Instruments';   //(Tag-itHF-I)
               BlockSize:= 4;
               BlockNum := 64;

               BlockStyle := 'A';   //type A
           end;
     //-------------------------------------------------------------------------
      $16 :                           //FirmCode $16
                                       //2006-8-2 add 'EM Microelectronic '
            begin
              FirmName := 'EM Microelectronic '  ;  //
              BlockSize:= 4;                      //
              BlockNum := 14;                     //
              BlockStyle := 'A';              // type A

            end;
        //------------------------------------------- --------------------------
       else
           result := False;
   end;
end;

Function RR9001_GetErrorCodeDesc(errorCode : Byte) : String;
begin
    result := '';
    case errorCode of
             CmdNotSupport         : result := 'Commands  not supported';
             CmdNotIdentify        : result := 'Unknown Command ';
            OperationNotSupport_  : result := 'Operation not supported';
            UnknownError          : result := 'Unknown error ';
            BlockError            : result := 'Appointed  block cant be used or does not exist';
            BlockLockedAndCntLock : result := 'Appointed  block is locked and cant be locked again.';
            BlockLockedAndCntWrite: result := 'Appointed  block is locked and its content can not be altered';
            BlockCntOperate       : result := 'Appointed  block cant be operated normally';
            BlockCntLock          : result := 'Appointed  block cant be locked normally';
    end;
end;

Function RR9001_GetReturnCodeDesc(retCode : Byte) : String;
begin
    result := '';
    case retCode of
           LengthError         : result := 'Command operand length error';
            OperationNotSupport : result := ' Command not supported';
            RfClosed            : result := 'RF field is inactive';
            EEPROM              : result := 'EEPROM operation error';
           TimeOut             : result := 'Inventory-Scan-Time overflow';
        MoreUID             : result := 'Not all tag''''s UIDs are collected before the Inventory-Scan-Time overflow';
        ISOError            : result := 'ISO error';        //ISO error
        NoElectronicTag     : result := 'No  Tags';
        OperationError      : result := 'Operation error';

       CommunicationErr    : result := 'Communication Error';
       RetCRCErr           : result := 'CRC checksummat Error';
      RetDataErr          : result := '';
      CommunicationBusy   : result := 'Communication busy';
    end;
end;

end.
